@@ -7,6 +7,7 @@ use Path::Tiny qw/path/;
 use Text::MicroTemplate qw/render_mt/;
 use Plack::Runner;
 use Pod::Usage;
+use App::revealup::util;
 
 my $_plack_port = 5000;
 my $_dry_run = 0;
@@ -27,7 +28,10 @@ sub run {
         pod2usage({-input => __FILE__, -verbose => 2, -output => \*STDERR});
     }
 
-    $_theme_path = path('.', $_theme) if $_theme;
+    if($_theme) {
+        $_theme .= '.css' if $_theme !~ m!.+\.css$!;
+        $_theme_path = path('.', $_theme);
+    }
     my $html = $self->render($filename);
     my $app = $self->app($html);
     my $runner = Plack::Runner->new();
@@ -38,7 +42,7 @@ sub run {
 
 sub render {
     my ($self, $filename) = @_;
-    my $template_dir = $self->share_path([qw/share templates/]);
+    my $template_dir = App::revealup::util::share_path([qw/share templates/]);
     my $template = $template_dir->child('slide.html.mt');
     my $content = $template->slurp_utf8();
     my $html = render_mt($content, $filename, $_theme_path, $_transition)->as_string();
@@ -64,37 +68,21 @@ sub app {
                 if($_theme_path->exists) {
                     $path = path('.', $_theme_path);
                 }else{
-                    my $reveal_theme_path = $self->share_path([qw/share revealjs css theme/]);
+                    my $reveal_theme_path = App::revealup::util::share_path([qw/share revealjs css theme/]);
                     $path = $reveal_theme_path->child($_theme_path->basename);
                 }
             }else{
-                my $reveal_dir = $self->share_path([qw/share revealjs/]);
+                my $reveal_dir = App::revealup::util::share_path([qw/share revealjs/]);
                 $path = $reveal_dir->child($env->{PATH_INFO});
             }
         }
-        return $self->path_to_res($path);
+        if( !$path->exists ) {
+            warn "[Warning] $path does not exist.\n";
+        }
+        return App::revealup::util::path_to_res($path);
     };
 }
 
-sub path_to_res {
-    my ($self, $path) = @_;
-    if( $path && $path->exists ) {
-        my $c = $path->slurp();
-        return [200, [ 'Content-Length' => length $c ], [$c]];
-    }
-    return [404, [], ['not found.']];
-}
-
-sub share_path {
-    my ($self, $p) = @_;
-    die "Parameter must be ARRAY ref" unless ref $p eq 'ARRAY';
-    my $path = path(@$p);
-    return $path if $path->exists();
-    shift @$p;
-    my $dist_dir = dist_dir('App-revealup');
-    return path($dist_dir, @$p);
-}
-
 1;
 
 __END__
@@ -105,19 +93,63 @@ __END__
 
 =head1 DESCRIPTION
 
-I<serve> commnad makes your markdown texts as a HTTP Web application for slideshow.
+I<serve> command makes your markdown texts as a HTTP Web application for slide show.
 Run C<revealup serve> the with markdown filename and options.
 And with your browser access such url I<http://localhost:5000/>.
 
-Options:
+=head1 Options
+
+=head2 -p or --port
+
+HTTP port number
+
+=head2 --theme
+
+CSS filename or original CSS file path. The reveal.js default CSS filenames are below.
 
 =over 4
 
-=item -p           : HTTP Port Number
+=item beige.css
 
-=item --theme      : CSS filename or path
+=item blood.css
 
-=item --transition : default/cube/page/concave/zoom/linear/fade/none
+=item default.css
+
+=item moon.css
+
+=item night.css
+
+=item serif.css
+
+=item simple.css
+
+=item sky.css
+
+=item solarized.css  
+
+=back
+
+=head2 --transition
+
+Trasition effects for slides.
+
+=over 4
+
+=item default
+
+=item cube
+
+=item page
+
+=item concave
+
+=item zoom
+
+=item linear
+
+=item fade
+
+=item none
 
 =back
 
